@@ -58,7 +58,7 @@ use v5.40;
 #
 
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Daje::Database::Model::ToolsProjects;
 use Daje::Database::Helper::TreeList;
@@ -382,11 +382,11 @@ CREATE TABLE IF NOT EXISTS tools_object_types
     insdatetime timestamp without time zone NOT NULL DEFAULT NOW(),
     modby varchar NOT NULL DEFAULT 'System',
     moddatetime timestamp without time zone NOT NULL DEFAULT NOW(),
-    name varchar not null UNIQUE,
+    type_name varchar not null UNIQUE,
     type bigint NOT NULL DEFAULT 0
 );
 
-INSERT INTO tools_object_types (name, type) VALUES
+INSERT INTO tools_object_types (type_name, type) VALUES
     ('Table', 1),
     ('Index', 2),
     ('SQL', 3),
@@ -571,6 +571,7 @@ CREATE TABLE IF NOT EXISTS tools_parameters
 INSERT INTO tools_parameters (parameter, tools_parameter_groups_fkey) VALUES
     ('Database Connection', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Project')),
     ('Output Path', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Sql')),
+    ('Template Source', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Sql')),
     ('Output file name', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Sql')),
     ('Output Name Space', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Sql')),
     ('Base file path', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Perl')),
@@ -604,6 +605,28 @@ CREATE TABLE IF NOT EXISTS tools_parameter_values
 );
 
 -- 11 down
+-- 12 up
+
+ALTER TABLE tools_object_tables
+    ADD COLUMN IF NOT EXISTS "notnull" BOOLEAN NOT NULL DEFAULT false,
+    ADD COLUMN IF NOT EXISTS "default" VARCHAR NOT NULL DEFAULT '';
+
+CREATE OR REPLACE VIEW v_tools_parameter_values AS
+select tools_parameter_values_pkey, parameter_group, parameter, value, description, active, tools_projects_fkey  from tools_parameter_groups
+	JOIN tools_parameters ON tools_parameter_groups_fkey = tools_parameter_groups_pkey
+	JOIN tools_parameter_values ON tools_parameters_fkey = tools_parameters_pkey
+
+CREATE OR REPLACE VIEW v_tools_objects_types AS
+select tools_objects.name, active, type, tools_version_fkey, tools_projects_fkey, tools_objects_pkey  from tools_objects JOIN tools_object_types
+	ON tools_object_types_pkey = tools_object_types_fkey
+
+CREATE OR REPLACE VIEW v_tools_objects_tables_datatypes AS
+	SELECT tools_object_tables_pkey, tools_version_fkey, tools_objects_fkey, fieldname, tools_object_tables.length, tools_object_tables.scale, tools_objects_tables_datatypes_fkey, active, visible, name as datatype, "notnull", "default"
+		FROM tools_object_tables JOIN tools_objects_tables_datatypes
+			ON tools_objects_tables_datatypes_fkey = tools_objects_tables_datatypes_pkey
+
+
+-- 12 down
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
